function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
import { h, defineComponent } from "vue";
import { TestBackend } from "react-dnd-test-backend";
import { HTML5Backend } from "react-dnd-html5-backend";
import { DndProvider } from "vue3-dnd";
/**
 * Wrap a Component with a DnDContext using the TestBackend
 *
 * @param DecoratedComponent The component to decorate
 * @param backendOptions
 * @returns [Component, getBackend] The wrapped component and a utility method
 * to get the test backend instance.
 */ export function wrapWithTestBackend(DecoratedComponent, backendOptions) {
    var backend;
    var opts = Object.assign({
        onCreate: function onCreate(be) {
            backend = be;
        }
    }, backendOptions);
    var result = wrapWithBackend(DecoratedComponent, TestBackend, opts);
    return [
        result,
        function() {
            return backend;
        }
    ];
}
/**
 * Wrap a component with a DndContext providing a backend.
 *
 * @param DecoratedComponent The compoent to decorate
 * @param Backend The backend to use (default=HTML5Backend)
 * @param backendOptions The optional backend options
 */ export function wrapWithBackend(DecoratedComponent) {
    var Backend = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : HTML5Backend, backendOptions = arguments.length > 2 ? arguments[2] : void 0;
    return defineComponent({
        render: function render() {
            var _this = this;
            return h(DndProvider, {
                backend: Backend,
                options: backendOptions
            }, {
                default: function() {
                    return h(DecoratedComponent, _objectSpread({}, _this.$attrs));
                }
            });
        }
    });
}
